define(
//begin v1.x content
({
        nomatchMessage: "A jelszavak nem egyeznek.",
		badPasswordMessage: "Érvénytelen jelszó."
})

//end v1.x content
);